@@ -1,6 +1,6 @@
 use {
     crate::{Chunk, Op},
-    koto_parser::ConstantIndex,
+    koto_parser::{ConstantIndex, MetaId},
     std::{convert::TryInto, fmt, sync::Arc},
 };
 
@@ -89,12 +89,12 @@ pub enum Instruction {
         register: u8,
         constant: ConstantIndex,
     },
-    LoadGlobal {
+    LoadExport {
         register: u8,
         constant: ConstantIndex,
     },
-    SetGlobal {
-        global: ConstantIndex,
+    SetExport {
+        export: ConstantIndex,
         source: u8,
     },
     Import {
@@ -172,14 +172,6 @@ pub enum Instruction {
         target: u8,
         source: u8,
     },
-    LoadCapture {
-        register: u8,
-        capture: u8,
-    },
-    SetCapture {
-        capture: u8,
-        source: u8,
-    },
     Negate {
         register: u8,
         source: u8,
@@ -274,6 +266,9 @@ pub enum Instruction {
     Yield {
         register: u8,
     },
+    Throw {
+        register: u8,
+    },
     Size {
         register: u8,
         value: u8,
@@ -339,6 +334,11 @@ pub enum Instruction {
         value: u8,
         key: ConstantIndex,
     },
+    MetaInsert {
+        register: u8,
+        value: u8,
+        id: MetaId,
+    },
     Access {
         register: u8,
         map: u8,
@@ -375,8 +375,8 @@ impl fmt::Display for Instruction {
             LoadFloat { .. } => write!(f, "LoadFloat"),
             LoadInt { .. } => write!(f, "LoadInt"),
             LoadString { .. } => write!(f, "LoadString"),
-            LoadGlobal { .. } => write!(f, "LoadGlobal"),
-            SetGlobal { .. } => write!(f, "SetGlobal"),
+            LoadExport { .. } => write!(f, "LoadExport"),
+            SetExport { .. } => write!(f, "SetExport"),
             Import { .. } => write!(f, "Import"),
             MakeTuple { .. } => write!(f, "MakeTuple"),
             MakeTempTuple { .. } => write!(f, "MakeTempTuple"),
@@ -393,8 +393,6 @@ impl fmt::Display for Instruction {
             MakeIterator { .. } => write!(f, "MakeIterator"),
             Function { .. } => write!(f, "Function"),
             Capture { .. } => write!(f, "Capture"),
-            LoadCapture { .. } => write!(f, "LoadCapture"),
-            SetCapture { .. } => write!(f, "SetCapture"),
             Negate { .. } => write!(f, "Negate"),
             Add { .. } => write!(f, "Add"),
             Subtract { .. } => write!(f, "Subtract"),
@@ -415,6 +413,7 @@ impl fmt::Display for Instruction {
             CallChild { .. } => write!(f, "CallChild"),
             Return { .. } => write!(f, "Return"),
             Yield { .. } => write!(f, "Yield"),
+            Throw { .. } => write!(f, "Throw"),
             Size { .. } => write!(f, "Size"),
             IterNext { .. } => write!(f, "IterNext"),
             IterNextTemp { .. } => write!(f, "IterNextTemp"),
@@ -429,6 +428,7 @@ impl fmt::Display for Instruction {
             ListUpdate { .. } => write!(f, "ListUpdate"),
             Index { .. } => write!(f, "Index"),
             MapInsert { .. } => write!(f, "MapInsert"),
+            MetaInsert { .. } => write!(f, "MetaInsert"),
             Access { .. } => write!(f, "Access"),
             TryStart { .. } => write!(f, "TryStart"),
             TryEnd => write!(f, "TryEnd"),
@@ -463,13 +463,13 @@ impl fmt::Debug for Instruction {
                 "LoadString\tresult: {}\tconstant: {}",
                 register, constant
             ),
-            LoadGlobal { register, constant } => write!(
+            LoadExport { register, constant } => write!(
                 f,
-                "LoadGlobal\tresult: {}\tconstant: {}",
+                "LoadExport\tresult: {}\tconstant: {}",
                 register, constant
             ),
-            SetGlobal { global, source } => {
-                write!(f, "SetGlobal\tglobal: {}\tsource: {}", global, source)
+            SetExport { export, source } => {
+                write!(f, "SetExport\texport: {}\tsource: {}", export, source)
             }
             Import { register, constant } => {
                 write!(f, "Import\t\tresult: {}\tconstant: {}", register, constant)
@@ -580,12 +580,6 @@ impl fmt::Debug for Instruction {
                 "Capture\t\tfunction: {}\ttarget: {}\tsource: {}",
                 function, target, source
             ),
-            LoadCapture { register, capture } => {
-                write!(f, "LoadCapture\tresult: {}\tcapture: {}", register, capture)
-            }
-            SetCapture { capture, source } => {
-                write!(f, "SetCapture\tcapture: {}\tsource {}", capture, source)
-            }
             Negate { register, source } => {
                 write!(f, "Negate\t\tresult: {}\tsource: {}", register, source)
             }
@@ -687,6 +681,7 @@ impl fmt::Debug for Instruction {
             ),
             Return { register } => write!(f, "Return\t\tresult: {}", register),
             Yield { register } => write!(f, "Yield\t\tresult: {}", register),
+            Throw { register } => write!(f, "Throw\t\tresult: {}", register),
             Size { register, value } => write!(f, "Size\t\tresult: {}\tvalue: {}", register, value),
             IterNext {
                 register,
@@ -782,6 +777,15 @@ impl fmt::Debug for Instruction {
                 "MapInsert\tmap: {}\t\tvalue: {}\tkey: {}",
                 register, value, key
             ),
+            MetaInsert {
+                register,
+                value,
+                id,
+            } => write!(
+                f,
+                "MetaInsert\tmap: {}\t\tvalue: {}\tid: {:?}",
+                register, value, id
+            ),
             Access { register, map, key } => write!(
                 f,
                 "Access\t\tresult: {}\tmap: {}\t\tkey: {}",
@@ -936,20 +940,20 @@ impl Iterator for InstructionReader {
                 register: get_byte!(),
                 constant: get_u32!() as ConstantIndex,
             }),
-            Op::LoadGlobal => Some(LoadGlobal {
+            Op::LoadExport => Some(LoadExport {
                 register: get_byte!(),
                 constant: get_byte!() as ConstantIndex,
             }),
-            Op::LoadGlobalLong => Some(LoadGlobal {
+            Op::LoadExportLong => Some(LoadExport {
                 register: get_byte!(),
                 constant: get_u32!() as ConstantIndex,
             }),
-            Op::SetGlobal => Some(SetGlobal {
-                global: get_byte!() as ConstantIndex,
+            Op::SetExport => Some(SetExport {
+                export: get_byte!() as ConstantIndex,
                 source: get_byte!(),
             }),
-            Op::SetGlobalLong => Some(SetGlobal {
-                global: get_u32!() as ConstantIndex,
+            Op::SetExportLong => Some(SetExport {
+                export: get_u32!() as ConstantIndex,
                 source: get_byte!(),
             }),
             Op::Import => Some(Import {
@@ -1047,14 +1051,6 @@ impl Iterator for InstructionReader {
                 target: get_byte!(),
                 source: get_byte!(),
             }),
-            Op::LoadCapture => Some(LoadCapture {
-                register: get_byte!(),
-                capture: get_byte!(),
-            }),
-            Op::SetCapture => Some(SetCapture {
-                capture: get_byte!(),
-                source: get_byte!(),
-            }),
             Op::Negate => Some(Negate {
                 register: get_byte!(),
                 source: get_byte!(),
@@ -1154,6 +1150,9 @@ impl Iterator for InstructionReader {
             Op::Yield => Some(Yield {
                 register: get_byte!(),
             }),
+            Op::Throw => Some(Throw {
+                register: get_byte!(),
+            }),
             Op::Size => Some(Size {
                 register: get_byte!(),
                 value: get_byte!(),
@@ -1224,6 +1223,25 @@ impl Iterator for InstructionReader {
                 value: get_byte!(),
                 key: get_u32!() as ConstantIndex,
             }),
+            Op::MetaInsert => {
+                let register = get_byte!();
+                let value = get_byte!();
+                let meta_id = get_byte!();
+                if let Ok(id) = meta_id.try_into() {
+                    Some(MetaInsert {
+                        register,
+                        value,
+                        id,
+                    })
+                } else {
+                    Some(Error {
+                        message: format!(
+                            "Unexpected meta id {} found at instruction {}",
+                            meta_id, op_ip
+                        ),
+                    })
+                }
+            }
             Op::Access => Some(Access {
                 register: get_byte!(),
                 map: get_byte!(),
