@@ -17,10 +17,10 @@ pub enum Op {
     LoadIntLong,      // register, constant[4]
     LoadString,       // register, constant
     LoadStringLong,   // register, constant[4]
-    LoadGlobal,       // register, constant
-    LoadGlobalLong,   // register, constant[4]
-    SetGlobal,        // global, source
-    SetGlobalLong,    // global[4], source
+    LoadExport,       // register, constant
+    LoadExportLong,   // register, constant[4]
+    SetExport,        // export, source
+    SetExportLong,    // export[4], source
     Import,           // register, constant
     ImportLong,       // register, constant[4]
     MakeTuple,        // register, start register, count
@@ -34,8 +34,6 @@ pub enum Op {
     MakeIterator,     // register, range
     Function,         // register, arg count, capture count, flags, size[2]
     Capture,          // function, target, source
-    LoadCapture,      // register, capture
-    SetCapture,       // capture, source
     Range,            // register, start, end
     RangeInclusive,   // register, start, end
     RangeTo,          // register, end
@@ -63,6 +61,7 @@ pub enum Op {
     CallChild,        // result, function, arg register, arg count, parent
     Return,           // register
     Yield,            // register
+    Throw,            // register
     IterNext,         // output, iterator, jump offset[2]
     IterNextTemp,     // output, iterator, jump offset[2]
     IterNextQuiet,    // iterator, jump offset[2]
@@ -75,6 +74,7 @@ pub enum Op {
     Index,            // result, list register, index register
     MapInsert,        // map register, value register, key constant
     MapInsertLong,    // map register, value register, key constant[4]
+    MetaInsert,       // map register, value register, key constant
     Access,           // register, value register, key
     AccessLong,       // register, value register, key[4]
     IsList,           // register, value
@@ -270,3 +270,17 @@ impl From<u8> for Op {
         unsafe { std::mem::transmute(op) }
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn check_op_count() {
+        assert_eq!(
+            Op::Unused255 as u8,
+            255,
+            "Op should have 256 entries (see impl From<u8> for Op)"
+        );
+    }
+}
